<?php
/**
 * @package     Joomla.Administrator
 * @subpackage  com_miniorange_mediarestriction
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */
/**
 * AccountSetup Controller
 *
 * @package     Joomla.Administrator
 * @subpackage  com_miniorange_mediarestriction
 * @since       0.0.9
 */
defined('_JEXEC') or die('Restricted access');
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Filesystem\File;


class MiniorangeMediaRestrictionControllerAccountsetup extends JControllerForm
{
    function __construct()
    {
        $this->view_list = 'accountsetup';
        parent::__construct();
    }

    function verifyCustomer()
    {
        $post = JFactory::getApplication()->input->post->getArray();

        $email = '';
        $password = '';

        if (MoMediaRestrictionUtility::check_empty_or_null($post['email']) || MoMediaRestrictionUtility::check_empty_or_null($post['password'])) {
            JFactory::getApplication()->enqueueMessage(4711, 'All the fields are required. Please enter valid entries.');
            return;
        } else {
            $email = $post['email'];
            $password = $post['password'];
        }

        $db = JFactory::getDbo();
 
		$query = $db->getQuery(true);
		 // Fields to update.
		$fields = array(
			$db->quoteName('email') . ' = '.$db->quote(1),
			$db->quoteName('password') . ' = ' . $db->quote(''),
			$db->quoteName('email_count') . ' = ' . $db->quote(0),
			$db->quoteName('sms_count') . ' = ' . $db->quote(0),
		);
		 
		// Conditions for which records should be updated.
		$conditions = array(
			$db->quoteName('id') . ' = 1'
		);
		 
		$query->update($db->quoteName('#__miniorange_mediarestriction_customer_details'))->set($fields)->where($conditions);
		$db->setQuery($query);
		$result = $db->execute();

        $customer = new MoMediaRestrictionCustomer();
        $content = $customer->get_customer_key($email, $password);

        $customerKey = json_decode($content, true);
        if (strcasecmp($customerKey['apiKey'], 'CURL_ERROR') == 0) {
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', $customerKey['token'], 'error');
        } else if (json_last_error() == JSON_ERROR_NONE) {
            if (isset($customerKey['id']) && isset($customerKey['apiKey']) && !empty($customerKey['id']) && !empty($customerKey['apiKey'])) {
                $this->save_customer_configurations($email, $customerKey['id'], $customerKey['apiKey'], $customerKey['token'], $customerKey['phone']);
                $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=media_restriction_upgrade', 'Your account has been retrieved successfully.');
            } else {
                $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'There was an error in fetching your details. Please try again.', 'error');
            }
        } else {
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Invalid username or password. Please try again.', 'error');
        }
    }

    
    function save_customer_configurations($email, $id, $apiKey, $token, $phone)
    {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        // Fields to update.
        $fields = array(
            $db->quoteName('email') . ' = ' . $db->quote($email),
            $db->quoteName('customer_key') . ' = ' . $db->quote($id),
            $db->quoteName('api_key') . ' = ' . $db->quote($apiKey),
            $db->quoteName('customer_token') . ' = ' . $db->quote($token),
            $db->quoteName('admin_phone') . ' = ' . $db->quote($phone),
            $db->quoteName('login_status') . ' = ' . $db->quote(0),
            $db->quoteName('registration_status') . ' = ' . $db->quote('SUCCESS'),
            $db->quoteName('password') . ' = ' . $db->quote(''),
            $db->quoteName('email_count') . ' = ' . $db->quote(0),
            $db->quoteName('sms_count') . ' = ' . $db->quote(0),
        );

        // Conditions for which records should be updated.
        $conditions = array(
            $db->quoteName('id') . ' = 1'
        );

        $query->update($db->quoteName('#__miniorange_mediarestriction_customer_details'))->set($fields)->where($conditions);
        $db->setQuery($query);
        $result = $db->execute();

        $msg = 'Your account has been retrieved successfully, now you can <strong>upgrade</strong> to licensed version.';
        $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=media_restriction_upgrade', $msg);
    }

    function ResetAccount()
    {
        
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $fields = array(
            $db->quoteName('email') . ' = ' . $db->quote(''),
            $db->quoteName('password') . ' = ' . $db->quote(''),
            $db->quoteName('customer_key') . ' = ' . $db->quote(''),
            $db->quoteName('admin_phone') . ' = ' . $db->quote(''),
            $db->quoteName('customer_token') . ' = ' . $db->quote(''),
            $db->quoteName('api_key') . ' = ' . $db->quote(''),
            $db->quoteName('registration_status') . ' = ' . $db->quote('NULL'),
            $db->quoteName('login_status') . ' = ' . $db->quote(0),
            $db->quoteName('transaction_id') . ' = ' . $db->quote(''),
            $db->quoteName('email_count') . ' = ' . $db->quote(0),
            $db->quoteName('sms_count') . ' = ' . $db->quote(0),
        );
        // Conditions for which records should be updated.
        $conditions = array(
            $db->quoteName('id') . ' = 1'
        );

        $query->update($db->quoteName('#__miniorange_mediarestriction_customer_details'))->set($fields)->where($conditions);
        $db->setQuery($query);
        $db->execute();
        $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account');
    }


    function cancelform()
    {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $fields = array(
            $db->quoteName('email') . ' = ' . $db->quote(''),
            $db->quoteName('password') . ' = ' . $db->quote(''),
            $db->quoteName('customer_key') . ' = ' . $db->quote(''),
            $db->quoteName('admin_phone') . ' = ' . $db->quote(''),
            $db->quoteName('customer_token') . ' = ' . $db->quote(''),
            $db->quoteName('api_key') . ' = ' . $db->quote(''),
            $db->quoteName('registration_status') . ' = ' . $db->quote(''),
            $db->quoteName('login_status') . ' = ' . $db->quote(0),
            $db->quoteName('transaction_id') . ' = ' . $db->quote(''),
            $db->quoteName('status') . ' = ' . $db->quote(''),
        );
        // Conditions for which records should be updated.
        $conditions = array(
            $db->quoteName('id') . ' = 1'
        );

        $query->update($db->quoteName('#__miniorange_mediarestriction_customer_details'))->set($fields)->where($conditions);
        $db->setQuery($query);
        $result = $db->execute();
        $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account');

    }

    function contactUs()
    {

        $post = JFactory::getApplication()->input->post->getArray();

        if (count($post) == 0) {
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account');
            return;
        }

        $query_email = isset($post['query_email']) ? $post['query_email'] : '';
        $query = isset($post['query_support']) ? $post['query_support'] : '';
        $phone = isset($post['query_phone']) ? $post['query_phone'] : '';

        if (MoMediaRestrictionUtility::check_empty_or_null($query_email) || MoMediaRestrictionUtility::check_empty_or_null($query)) {
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Please submit your query with email.', 'error');
            return;
        } else {
            $contact_us = new MoMediaRestrictionCustomer();
            $submited = $contact_us->submit_contact_us($query_email, $phone, $query);
       
            if (json_last_error() == JSON_ERROR_NONE) {
                if (is_array($submited) && array_key_exists('status', $submited) && $submited['status'] == 'ERROR') {
                    $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', $submited['message'], 'error');
                } else {
                    if ($submited != 'Query submitted.') {
                        $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Your query could not be submitted. Please try again.', 'error');
                    } else {
                        $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Thanks for getting in touch! We will get back to you shortly.');
                    }
                }
            }
        }
    }

    function saveFileRestriction()
    {
        
        $post = JFactory::getApplication()->input->post->getArray();

        if (count($post) == 0) {
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=rolebased_access_settings');
            return;
        }

        $enable_media_restriction =  isset($post['mo_enable_media_restriction']) ? $post['mo_enable_media_restriction'] : 0;
        $mo_media_restriction_file_types =  array_key_exists('mo_media_restriction_file_types', $post) ? json_decode($post['mo_media_restriction_file_types']) : array();  
        $mo_file_types='';
        $files_types_allowed=array('png', 'jpg', 'gif', 'pdf', 'doc');
        if(!empty( $mo_media_restriction_file_types))
        {
          foreach($mo_media_restriction_file_types as $files)
          {
            if(in_array($files->value,$files_types_allowed))
            {
                $mo_file_types.=$files->value.',';
            }
            
          }   
        }

       
        //update
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $fields = array(
            $db->quoteName('enable_media_restriction') . ' = ' . $db->quote($enable_media_restriction),
            $db->quoteName('mo_media_restriction_file_types') . ' = ' . $db->quote($mo_file_types),
        );
        // Conditions for which records should be updated.
        $conditions = array(
            $db->quoteName('id') . ' = 1'
        );

        $query->update($db->quoteName('#__miniorange_mediarestriction_settings'))->set($fields)->where($conditions);
        $db->setQuery($query);
        $db->execute();

        $database_name = '#__miniorange_mediarestriction_customer_details';
        $updatefieldsarray = array(
            'save_configuration' => 1,
        );
        MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);

        $customer = new MoMediaRestrictionCustomer();
        $customer->submit_feedback_form('','Save Configuration','Successfully saved configuration.');

        $message = 'Your configuration has been saved successfully. Now click on Show Rules button and write rules in .htaccess file';
        $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=media_restriction_settings', $message,'success');
    
    }


    function writeHtaccess()
    {
        $customer_details = MoMediaRestrictionUtility::getCustomerDetails();
       
        $home_path=JPATH_ROOT;
        $htaccess_file = $home_path.'\.htaccess';
        $insertion = MoMediaRestrictionUtility::getRules();
        if(file_exists($htaccess_file) && is_writable($home_path) && is_writeable($htaccess_file)){
            $htaccess_file_backup = $home_path.'\.miniorange-htaccess-backup';
            copy($htaccess_file, $home_path.'\.miniorange-htaccess-backup');
            MoMediaRestrictionUtility::insertRules($htaccess_file,$insertion);
            $database_name = '#__miniorange_mediarestriction_customer_details';
            $updatefieldsarray = array(
                'created_file' => 1,
            );
            MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
            $customer = new MoMediaRestrictionCustomer();
            $customer->submit_feedback_form('', 'Create File','File updated correctly');
            $message = '.htaccess file has been updated successfully';
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=media_restriction_settings', $message);
        }else{
            if(is_writable($home_path)){
               
                if(file_exists($htaccess_file))
                    copy($htaccess_file, $home_path.'\.miniorange-htaccess-backup');
                else{
                    MoMediaRestrictionUtility::show_popup();
                }
                    
            }else
            {
                $database_name = '#__miniorange_mediarestriction_customer_details';
                $updatefieldsarray = array(
                    'created_file' => 1,
                );
                MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                $customer = new MoMediaRestrictionCustomer();
                $customer->submit_feedback_form('','Create File','Do not have access to file.');
                $message = 'Dont have write access to file or folder ';
                $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=media_restriction_settings', $message, 'error');
            }
        }
       
    }

    function createHtaccess()
    {
        $home_path=JPATH_ROOT;
        $htaccess_file = $home_path.'\.htaccess';
        $htaccess_txt_file = $home_path.'\htaccess.txt';
        $insertion = MoMediaRestrictionUtility::getRules();
        $start_marker='# BEGIN MINIORANGE MEDIA RESTRICTION';
        $end_marker='# END MINIORANGE MEDIA RESTRICTION ';
        $fp = fopen( $htaccess_txt_file, 'r+' );
        $lines = array();
        while ( ! feof( $fp ) ) {
            $lines[] = rtrim( fgets( $fp ), "\r\n" );
        }
        $insertion_rule=implode("\n", 
        array_merge(
        array( $start_marker ),
        $insertion,
        array( $end_marker ),
        $lines
        ));
        File::write($htaccess_file, $insertion_rule);
        copy($htaccess_txt_file, $home_path.'\.miniorange-htaccess-backup');
        $customer = new MoMediaRestrictionCustomer();
        $customer->submit_feedback_form('', 'Create File','File created successfully');
        $message = '.htaccess file has been created successfully and added rules in the file';
        $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=media_restriction_settings', $message);
    }

    function cancelPopup()
    {
        $message = 'Please create .htaccess file mannualy and add rules in the file';
        $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=media_restriction_settings',$message, 'error');
    }

    function customerLoginForm()
    {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $fields = array(
            $db->quoteName('login_status') . ' = ' . $db->quote(1),
            $db->quoteName('password') . ' = ' . $db->quote(''),
            $db->quoteName('sms_count') . ' = ' . $db->quote(0),
        );
        // Conditions for which records should be updated.
        $conditions = array(
            $db->quoteName('id') . ' = 1'
        );

        $query->update($db->quoteName('#__miniorange_mediarestriction_customer_details'))->set($fields)->where($conditions);
        $db->setQuery($query);
        $db->execute();
        $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account');
    }

    function cancelLoginform()
    {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $fields = array(
            $db->quoteName('registration_status') . ' = ' . $db->quote(''),
            $db->quoteName('login_status') . ' = ' . $db->quote(0),
            $db->quoteName('email_count') . ' = ' . $db->quote(0),
            $db->quoteName('sms_count') . ' = ' . $db->quote(0),
        );
      
        $conditions = array(
            $db->quoteName('id') . ' = 1'
        );

        $query->update($db->quoteName('#__miniorange_mediarestriction_customer_details'))->set($fields)->where($conditions);
        $db->setQuery($query);
        $db->execute();
        $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account');
    }
    
    function registerCustomer()
    {
        $post = JFactory::getApplication()->input->post->getArray();
        if (count($post) == 0) {
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account');
            return;
        }
        $email = '';
        $phone = '';
        $password = '';
        $confirmPassword = '';

        if (MoMediaRestrictionUtility::check_empty_or_null($post['email']) || MoMediaRestrictionUtility::check_empty_or_null($post['password']) || MoMediaRestrictionUtility::check_empty_or_null($post['confirmPassword'])) {
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'All the fields are required. Please enter valid entries.', 'error');
            return;
        } else if (strlen($post['password']) < 6 || strlen($post['confirmPassword']) < 6) {    //check password is of minimum length 6
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Choose a password with minimum length 6.', 'error');
            return;
        } else {
            $email = $post['email'];
            $phone = $post['phone'];
            $password = $post['password'];
            $confirmPassword = $post['confirmPassword'];
        }

        if (strcmp($password, $confirmPassword) == 0) {
            $db = JFactory::getDbo();
            $query = $db->getQuery(true);
            $fields = array(
                $db->quoteName('email') . ' = ' . $db->quote($email),
                $db->quoteName('admin_phone') . ' = ' . $db->quote($phone ),
                $db->quoteName('password') . ' = ' . $db->quote(base64_encode($password)),
            );
          
            $conditions = array(
                $db->quoteName('id') . ' = 1'
            );
    
            $query->update($db->quoteName('#__miniorange_mediarestriction_customer_details'))->set($fields)->where($conditions);
            $db->setQuery($query);
            $db->execute();

            $customer = new MoMediaRestrictionCustomer();
            $content = json_decode($customer->check_customer($email), true);
         
            if (strcasecmp($content['status'], 'CUSTOMER_NOT_FOUND') == 0) {
                $auth_type = 'EMAIL';
                $content = json_decode($customer->send_otp_token($auth_type, null), true);
             
                if (strcasecmp($content['status'], 'SUCCESS') == 0) {
                    $database_name = '#__miniorange_mediarestriction_customer_details';
                    $updatefieldsarray = array(
                        'email_count' => '1',
                        'transaction_id' => $content['txId'],
                        'registration_status' => 'MO_OTP_DELIVERED_SUCCESS',
                    );

                    MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                    $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'A One Time Passcode(OTP) has been sent to <strong>' . $email . '</strong>. Please enter the OTP to verify your email. ');
                } else {
                    $database_name = '#__miniorange_mediarestriction_customer_details';
                    $updatefieldsarray = array(
                        'registration_status' => 'MO_OTP_DELIVERED_FAILURE',
                    );

                    MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                    $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'There is an error in sending OTP. Please click on Resend OTP to try again. ', 'error');
                    return;
                }
            }else if (strcasecmp($content['status'], 'CURL_ERROR') == 0) {
                $database_name = '#__miniorange_mediarestriction_customer_details';
                $updatefieldsarray = array(
                    'registration_status' => 'MO_OTP_DELIVERED_FAILURE',
                );

                MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', $content['statusMessage'], 'error');
                return;
            } else if (strcasecmp($content['status'], 'TRANSACTION_LIMIT_EXCEEDED') == 0) {
                $database_name = '#__miniorange_mediarestriction_customer_details';
                $updatefieldsarray = array(
                    'login_status' => 1,
                    'registration_status' => '',
                );

                MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Server is busy. Please contact us at joomlasupport@xecurify.com or <a href=\'http://miniorange.com/contact\' target=\'_blank\'>click here</a> to contact us for support. We will reach back to you! ', 'error');
                return;
            } else {
                $content = $customer->get_customer_key($email, $password);
                $customerKey = json_decode($content, true);
                if (json_last_error() == JSON_ERROR_NONE) {
                    $this->saveSuccessCustomer($customerKey, 'Your account has been retrieved successfully, now you can <strong>upgrade</strong> to licensed version.', $email);

                    $database_name = '#__miniorange_mediarestriction_customer_details';
                    $updatefieldsarray = array('password' => '',);
                    MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                } else {
                    $database_name = '#__miniorange_mediarestriction_customer_details';
                    $updatefieldsarray = array(
                        'login_status' => 1,
                        'new_registration' => 0,
                        'password' => '',
                    );

                    MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                    $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'You already have an account with miniOrange. Please enter a valid password.', 'error');
                    return;
                }
            }
        }
        else
        {
            $database_name = '#__miniorange_mediarestriction_customer_details';
            $updatefieldsarray = array('login_status' => 0,);
            MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Password and Confirm password do not match.', 'error');
            return;
        }

    }

    function resendOtp()
    {
        $customer = new MoMediaRestrictionCustomer();
        $auth_type = 'EMAIL';
        $content = json_decode($customer->send_otp_token($auth_type, null), true);
        if (strcasecmp($content['status'], 'SUCCESS') == 0) {
            $customer_details = MoMediaRestrictionUtility::getCustomerDetails();
            $email_count = $customer_details['email_count'];
            $admin_email = $customer_details['email'];
            if ($email_count != '') {
                $email_count = $email_count + 1;
                $database_name = '#__miniorange_mediarestriction_customer_details';
                $updatefieldsarray = array(
                    'email_count' => $email_count,
                    'transaction_id' => $content['txId'],
                    'registration_status' => 'MO_OTP_DELIVERED_SUCCESS',
                );

                MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Another One Time Passcode has been sent to <strong>' . ($admin_email) . '</strong>. Please enter the OTP below to verify your email.');
            } else {
                $database_name = '#__miniorange_mediarestriction_customer_details';
                $updatefieldsarray = array('registration_status' => 'MO_OTP_DELIVERED_SUCCESS',);
                MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'An OTP has been sent to <strong>' . ($admin_email) . '</strong>. Please enter the OTP below to verify your email.');
            }
        } else if (strcasecmp($content['status'], 'CURL_ERROR') == 0) {
            $database_name = '#__miniorange_mediarestriction_customer_details';
            $updatefieldsarray = array('registration_status' => 'MO_OTP_DELIVERED_FAILURE',);
            MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', $content['statusMessage'], 'error');
            return;
        } else {
            $database_name = '#__miniorange_mediarestriction_customer_details';
            $updatefieldsarray = array('registration_status' => 'MO_OTP_DELIVERED_FAILURE',);
            MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'There is an error in sending OTP. Please click on Resend OTP to try again.', 'error');
            return;
        }
    }

    function phoneVerification()
    {
        $post = JFactory::getApplication()->input->post->getArray();
        if (count($post) == 0) {
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account');
            return;
        }
        $phone = $post['phone_number'];
        $phone = str_replace(' ', '', $phone);
        $pattern = "/[\+][0-9]{1,3}[0-9]{10}/";
        if (preg_match($pattern, $phone, $matches, PREG_OFFSET_CAPTURE)) {
            $auth_type = 'SMS';
            $customer = new MoMediaRestrictionCustomer();
            $send_otp_response = json_decode($customer->send_otp_token($auth_type, $phone));
            if ($send_otp_response->status == 'SUCCESS') {
                $customer_details = MoMediaRestrictionUtility::getCustomerDetails();
                $sms_count = $customer_details['sms_count'];
                if ($sms_count != '') {
                    $sms_count = $sms_count + 1;
                    $database_name = '#__miniorange_mediarestriction_customer_details';
                    $updatefieldsarray = array('sms_count' => $sms_count,
                        'transaction_id' => $send_otp_response->txId,
                    );
                    MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                    $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Another One Time Passcode has been sent <strong>(' . $sms_count . ')</strong> for verification to ' . $phone);
                } else {
                    $database_name = '#__miniorange_mediarestriction_customer_details';
                    $updatefieldsarray = array('sms_count' => 1,
                        'transaction_id' => $send_otp_response->txId,
                    );
                    MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                    $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'One Time Passcode has been sent ( <strong>1</strong> ) for verification to ' . $phone);
                }
            }
        } else {
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Please enter the phone number in the following format: <strong>+##country code## ##phone number##', 'error');
            return;
        }
    }


    function validateOtp()
    {
        //validation and sanitization
        $post = JFactory::getApplication()->input->post->getArray();

        if (!isset($post['otp_token'])) {
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account');
            return;
        }
        $otp_token = '';

        if (MoMediaRestrictionUtility::check_empty_or_null($post['otp_token'])) {

            $database_name = '#__miniorange_mediarestriction_customer_details';
            $updatefieldsarray = array('registration_status' => 'MO_OTP_VALIDATION_FAILURE',);
            MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Please enter a value in otp field.', 'error');
            return;
        } else {
            $otp_token = trim($post['otp_token']);
        }

     
        $customer_details = MoMediaRestrictionUtility::getCustomerDetails();
        $transaction_id = $customer_details['transaction_id'];

        $customer = new MoMediaRestrictionCustomer();
        $content = json_decode($customer->validate_otp_token($transaction_id, $otp_token), true);

        if (strcasecmp($content['status'], 'SUCCESS') == 0) {

            $customerKey = json_decode($customer->create_customer(), true);
            $database_name = '#__miniorange_mediarestriction_customer_details';
            $updatefieldsarray = array(
                'email_count' => 0,
                'sms_count' => 0,
            );
            MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);

            if (strcasecmp($customerKey['status'], 'CUSTOMER_USERNAME_ALREADY_EXISTS') == 0) {    //admin already exists in miniOrange
                $content = $customer->get_customer_key($transaction_id['email'], $transaction_id['password']);
                $customerKey = json_decode($content, true);
                if (json_last_error() == JSON_ERROR_NONE) {
                    $this->saveSuccessCustomer($customerKey, 'Your account has been created successfully.', '');
                } else {
                    $database_name = '#__miniorange_mediarestriction_customer_details';
                    $updatefieldsarray = array(
                        'registration_status' => 'false',
                        'login_status' => 1,
                        'password' => '',
                    );
                    MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                    $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'You already have an account with miniOrange. Please enter a valid password.', 'error');
                    return;
                }
            } else if (strcasecmp($customerKey['status'], 'INVALID_EMAIL') == 0) {
                $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Invalid Email ID. Please use a valid Email ID to register .', 'error');
                return;
            } else if (strcasecmp($customerKey['status'], 'SUCCESS') == 0) {
                $database_name = '#__miniorange_mediarestriction_customer_details';
                $updatefieldsarray = array(
                    'password' => '',
                );
                MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);

                //registration successful
                $this->saveSuccessCustomer($customerKey, 'Registration complete!', '');
            } else if (strcmp($customerKey['message'], 'Email is not enterprise email.') == 0) {
                $database_name = '#__miniorange_mediarestriction_customer_details';
                $updatefieldsarray = array(
                    'registration_status' => '',
                    'email' => '',
                    'password' => '',
                    'transaction_id' => '',
                );
                MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'There was an error creating an account for you. You may have entered an invalid Email-Id. <br><strong>(We discourage the use of disposable emails)</strong><br>
											Please try again with a valid email.', 'error');
                return;
            } else {
                $database_name = '#__miniorange_mediarestriction_customer_details';
                $updatefieldsarray = array(
                    'registration_status' => '',
                    'email' => '',
                    'password' => '',
                    'transaction_id' => '',
                );
                MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
                $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'There was an error creating an account for you. You may have entered an invalid Email-Id. <br><strong>(We discourage the use of disposable emails)</strong><br>
											Please try again with a valid email.', 'error');
                return;
            }
        } else if (strcasecmp($content['status'], 'INVALID_EMAIL_QUICK_EMAIL') == 0) {
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'There was an error creating an account for you.
                            You may have entered an invalid Email-Id. <br><strong>(We discourage the use of disposable emails)</strong><br>Please go back and try again with a valid email.', 'error');
            return;
        } else if ($content['status'] == 'FAILED') {
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'An error occured, while processing your request.', 'error');
            return;
        } else if (strcasecmp($content['status'], 'CURL_ERROR') == 0) {
            $database_name = '#__miniorange_mediarestriction_customer_details';
            $updatefieldsarray = array(
                'registration_status' => 'MO_OTP_VALIDATION_FAILURE',
            );

            MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', $content['statusMessage'], 'error');
            return;
        } else {
            $database_name = '#__miniorange_mediarestriction_customer_details';
            $updatefieldsarray = array(
                'registration_status' => 'MO_OTP_VALIDATION_FAILURE',
            );

            MoMediaRestrictionUtility::generic_update_query($database_name, $updatefieldsarray);
            $this->setRedirect('index.php?option=com_miniorange_mediarestriction&view=accountsetup&tab-panel=account', 'Invalid one time passcode(OTP). Please enter a valid OTP.', 'error');
            return;
        }
    }

    
    function saveSuccessCustomer($customerKey, $message, $email = '')
    {
        if (empty($email)) {
            $email = isset($customerKey['email']) ? $customerKey['email'] : '';
        }
        $apiKey = isset($customerKey['apiKey']) ? $customerKey['apiKey'] : '';
        $token = isset($customerKey['token']) ? $customerKey['token'] : '';
        $phone = isset($customerKey['phone']) ? $customerKey['phone'] : '';
        $customerId = isset($customerKey['id']) ? $customerKey['id'] : '';
        $this->save_customer_configurations($email, $customerId, $apiKey, $token, $phone);

    }

}